summaryrefslogtreecommitdiff
path: root/ufs/dir.c
diff options
context:
space:
mode:
authorMichael I. Bushnell <mib@gnu.org>1996-04-03 21:08:58 +0000
committerMichael I. Bushnell <mib@gnu.org>1996-04-03 21:08:58 +0000
commit85ae67dbee7e957c859144a1e09cba5a38275568 (patch)
tree2b3a35b9ab049d1b2b848b8429aeb2da6fcdc9e9 /ufs/dir.c
parent10a64e4de4c86ddc50b1e7e48cd61acf3b09f386 (diff)
(diskfs_lookup_hard):
Diffstat (limited to 'ufs/dir.c')
-rw-r--r--ufs/dir.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/ufs/dir.c b/ufs/dir.c
index 0a109c0c..136b470f 100644
--- a/ufs/dir.c
+++ b/ufs/dir.c
@@ -196,7 +196,7 @@ diskfs_lookup_hard (struct node *dp, char *name, enum lookup_type type,
goto out;
}
/* We can't just do iget, because we would then deadlock.
So we do this. Ick. */
else if (retry_dotdot)
{
@@ -207,7 +207,7 @@ diskfs_lookup_hard (struct node *dp, char *name, enum lookup_type type,
try *again*. */
diskfs_nput (np);
mutex_unlock (&dp->lock);
- err = iget (inum, &np);
+ err = diskfs_cached_lookup (inum, &np);
mutex_lock (&dp->lock);
if (err)
goto out;
@@ -222,7 +222,7 @@ diskfs_lookup_hard (struct node *dp, char *name, enum lookup_type type,
repeat the directory scan to see if this is still
right. */
mutex_unlock (&dp->lock);
- err = iget (inum, &np);
+ err = diskfs_cached_lookup (inum, &np);
mutex_lock (&dp->lock);
if (err)
goto out;
@@ -237,7 +237,7 @@ diskfs_lookup_hard (struct node *dp, char *name, enum lookup_type type,
else if (type == LOOKUP)
{
diskfs_nput (dp);
- err = iget (inum, &np);
+ err = diskfs_cached_lookup (inum, &np);
if (err)
goto out;
}
@@ -289,7 +289,7 @@ diskfs_lookup_hard (struct node *dp, char *name, enum lookup_type type,
no new references, so we don't have anything to do */
;
else if (type == LOOKUP)
- /* We did iget */
+ /* We did diskfs_cached_lookup */
diskfs_nput (np);
}
else
@@ -196,7 +196,7 @@ diskfs_lookup_hard (struct node *dp, char *name, enum lookup_type type,
goto out;
}
- /* We can't just do iget, because we would then deadlock.
+ /* We can't just do diskfs_cached_lookup, because we would then deadlock.
So we do this. Ick. */
else if (retry_dotdot)